summaryrefslogtreecommitdiffstats
path: root/src/rip/k3bcddbpatternwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/rip/k3bcddbpatternwidget.cpp')
-rw-r--r--src/rip/k3bcddbpatternwidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rip/k3bcddbpatternwidget.cpp b/src/rip/k3bcddbpatternwidget.cpp
index 89c9554..79e1375 100644
--- a/src/rip/k3bcddbpatternwidget.cpp
+++ b/src/rip/k3bcddbpatternwidget.cpp
@@ -26,14 +26,14 @@
#include <tqvalidator.h>
#include <tqwhatsthis.h>
#include <tqcheckbox.h>
-#include <layout.h>
+#include <tqlayout.h>
K3bCddbPatternWidget::K3bCddbPatternWidget( TQWidget* parent, const char* name )
: base_K3bCddbPatternWidget( parent, name )
{
- // fix the layout
- ((TQGridLayout*)layout())->setRowStretch( 4, 1 );
+ // fix the tqlayout
+ ((TQGridLayout*)tqlayout())->setRowStretch( 4, 1 );
// setup validators
// there can never be one of the following characters in both dir and filename: